#
# spec file for package kf6-solid
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname solid
%bcond_without released
Name:           kf6-solid
Version:        6.10.0
Release:        1.1
Summary:        KDE Desktop hardware abstraction
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  bison
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(libimobiledevice-1.0)
BuildRequires:  pkgconfig(libplist-2.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(mount)

%description
Solid is a device integration framework. It provides a way of querying and
interacting with hardware independently of the underlying operating system.

%package tools
Summary:        KDE Desktop hardware abstraction

%description tools
Solid is a device integration framework. It provides a way of querying and
interacting with hardware independently of the underlying operating system.
CLI utilities.

%package -n libKF6Solid6
Summary:        KDE Desktop hardware abstraction
Requires:       kf6-solid >= %{version}
Recommends:     kf6-solid-tools = %{version}
Recommends:     media-player-info
Recommends:     udisks2

%description -n libKF6Solid6
Solid is a device integration framework. It provides a way of querying and
interacting with hardware independently of the underlying operating system.

%package devel
Summary:        KDE Desktop hardware abstraction: Build Environment
Requires:       libKF6Solid6 = %{version}
Requires:       cmake(Qt6Core) >= %{qt6_version}

%description devel
Solid is a device integration framework. It provides a way of querying and
interacting with hardware independently of the underlying operating system.
Development files.

%lang_package -n libKF6Solid6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE \

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang solid6 --with-qt --without-mo

%ldconfig_scriptlets -n libKF6Solid6

%files -n libKF6Solid6-lang -f solid6.lang

%files
%{_kf6_debugdir}/solid.categories
%{_kf6_debugdir}/solid.renamecategories

%files tools
%{_kf6_bindir}/solid-hardware6

%files -n libKF6Solid6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6Solid.so.*

%files devel
%doc %{_kf6_qchdir}/KF6Solid.*
%{_kf6_includedir}/Solid/
%{_kf6_cmakedir}/KF6Solid/
%{_kf6_libdir}/libKF6Solid.so

%changelog
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.1:
  * [UPowerManager] Also print error message on failure
* Sat Dec 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.1
  * Add null check for StorageAccess interface in
    storageAccessFromPath (kde#497299)
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * battery: Add cycleCount
  * Bump KF and QT versions in cem_set_disabled_deprecation_versions
  * fstab: Fix memory leak when a network or overlay mount has changed
  * Fix build on Haiku
  * Consistenly use correct include statements for libmount
  * Add support for rclone mounts and fstab entries
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Restore MediaChanged handling for Audio CDs
  * Support reproducible builds by omitting host paths in bison/yacc outputs
  * [udisks] Don't add/remove devices in slotMediaChanged
  * Port implicit QByteArray, QChar and QString conversions in iokit
  * Drop unfinished Power API
  * fstabwatcher: use libmount monitor on Linux
  * fstabhandling: use libmount in Linux
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * fstab: add missing signal override
  * fstab: Emit accessibilityChanged only when actually changed
  * Get rid of implicit QString and QChar conversions
  * Get rid of implicit QByteArray to const char* conversions
  * [Fstab] Minor cleanups (new style connect, extraneous include)
  * [Fstab] Remove mntent wrapper macros
  * [Fstab] Remove remnants of Solaris support
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * ci: add Alpine/musl job
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Update version to 6.5.0
  * udev/cpuinfo_arm: add M2 Pro/Max core variants
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Fix "Connecting from COMPAT signal" warning
  * support USE_DBUS option to enable/disable dbus use
  * Narrow down types of backend objects to Ifaces::DeviceManager
  * Doc: Port 0 to nullptr
  * Drop a reference to non-existent interface class
  * Add missing forward declaration
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- No code changes since 6.2.0
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * remove too aggressive assert (kde#464149)
  * [StorageAccess] Fix storageAccessFromPath returning unmounted filesystems
  * [SolidHwTest] Extend FakeHW description with encrypted volume, add tests
  * [SolidHwTest] Test Device::storageAccessFromPath
  * [DeviceManager] Remove exists() check from storageAccessFromPath
  * udisks: Return empty string for "root" clearTextPath (kde#485507)
  * [SolidHwTest] Remove unnecessary slotPropertyChanged helper, fix bug
  * [SolidHwTest] Remove setenv wrapper, unnecessary qt_windows.h include
  * [SolidHwTest] Move test class declaration to source file
  * udisks2: Add support CanCheck/Check/CanRepair/Repair
- Drop patch, merged upstream:
  * 0001-udisks-Return-empty-string-for-root-clearTextPath.patch
* Thu Apr 18 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix mounting encrypted drives (kde#485507, boo#1222980):
  * 0001-udisks-Return-empty-string-for-root-clearTextPath.patch
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * udisks2: Read CleartextDevice instead of introspection
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-solid
